California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 016 - NEW TWO-THIRDS VOTE REQUIREMENT FOR LOCAL PUBLIC ELECTRICITY PROVIDERS. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1318623 | YES ON 16 / CALIFORNIANS TO PROTECT OUR RIGHT TO VOTE MAJOR FUNDING FROM PACIFIC GAS & ELECTRIC COMPANY AND CA BUSINESS PAC, SPONSORED BY CA CHAMBER OF COMMERCE, A COALITION OF TAXPAYERS, BUSINE... | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1321957 | NO ON PROP 16, STOP THE PG&E POWERGRAB, SPONSORED BY LOCAL POWER AND THE UTILITY REFORM NETWORK | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1326873 | RATEPAYERS, BUSINESSES AND GOVERNMENTS OPPOSE PROP 16-STOP THE POWER GRAB | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1327180 | SIERRA CLUB SF BAY CHAPTER ISSUES | OPPOSE